==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>Hatch</name>
    <message>
        <location filename="../Hatch.js" line="+56"/>
        <source>No boundary selected.</source>
        <translation>輪郭が選択されていません。</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Loop not closed at point %1/%2.</source>
        <translation>ループは点 %1/%2 で閉じていません。</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translation>各輪郭は線分、弧、円、楕円弧、楕円、ポリラインまたはスプラインでなければなりません。 発見:</translation>
    </message>
    <message>
        <location filename="../HatchInit.js" line="+2"/>
        <source>&amp;Hatch</source>
        <translation>&amp;H ハッチング</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw hatch or solid fill</source>
        <translation>ハッチングまたは全面色を描画</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translation>ハッチング</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Type</source>
        <translation>タイプ</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translation>全面色</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translation>ハッチパターン</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translation>プレビュー</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translation>パターン</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translation>角度:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translation>縮尺:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Hatch</name>
    <message>
        <source>No boundary selected.</source>
        <translation type="vanished">輪郭が選択されていません。</translation>
    </message>
    <message>
        <source>Loop not closed at point %1/%2.</source>
        <translation type="vanished">ループは点 %1/%2 で閉じていません。</translation>
    </message>
    <message>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translation type="vanished">各輪郭は線分、弧、円、楕円弧、楕円、ポリラインまたはスプラインでなければなりません。 発見:</translation>
    </message>
    <message>
        <location filename="../Hatch.js" line="+72"/>
        <source>Hatch Tools</source>
        <translation>ハッチングツール</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show hatch tools</source>
        <translation>ハッチングツールを表示</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Hatch</source>
        <translation>&amp;H ハッチング</translation>
    </message>
    <message>
        <source>Draw hatch or solid fill</source>
        <translation type="vanished">ハッチングまたは全面色を描画</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translation>ハッチング</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Type</source>
        <translation>タイプ</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translation>全面色</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translation>ハッチパターン</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translation>プレビュー</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translation>パターン</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translation>角度:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translation>縮尺:</translation>
    </message>
</context>
</TS>
